Struct transaction_emitter::TxnEmitter[][src]

pub struct TxnEmitter<'t, 'd> { /* fields omitted */ }

Implementations

workflow of mint accounts:

  1. mint faucet account as the money source
  2. load tc account to create seed accounts(parent VASP), one seed account for each endpoint
  3. mint coins from faucet to new created seed accounts
  4. split number of requested accounts(child VASP) into equally size of groups
  5. each seed account take responsibility to create one size of group requested accounts and mint coins to them example: requested totally 100 new accounts with 10 endpoints will create 10 seed accounts(parent VASP), each seed account create 10 new accounts