Struct transaction_emitter::TxnEmitter [−][src]
pub struct TxnEmitter<'t, 'd> { /* fields omitted */ }Implementations
pub fn new(
treasury_compliance_account: &'t mut LocalAccount,
designated_dealer_account: &'d mut LocalAccount,
client: RestClient,
transaction_factory: TransactionFactory,
rng: StdRng
) -> Self
pub async fn load_vasp_account(
&self,
client: &RestClient,
index: usize
) -> Result<LocalAccount>
pub async fn get_seed_accounts(
&mut self,
rest_clients: &[RestClient],
seed_account_num: usize,
vasp: bool
) -> Result<Vec<LocalAccount>>
pub async fn mint_accounts(
&mut self,
req: &EmitJobRequest,
total_requested_accounts: usize
) -> Result<()>
pub async fn mint_accounts(
&mut self,
req: &EmitJobRequest,
total_requested_accounts: usize
) -> Result<()>
workflow of mint accounts:
- mint faucet account as the money source
- load tc account to create seed accounts(parent VASP), one seed account for each endpoint
- mint coins from faucet to new created seed accounts
- split number of requested accounts(child VASP) into equally size of groups
- each seed account take responsibility to create one size of group requested accounts and mint coins to them example: requested totally 100 new accounts with 10 endpoints will create 10 seed accounts(parent VASP), each seed account create 10 new accounts